"""moles-tools: A collection of Python tools from the underground."""

__version__ = "0.1.0"
__author__ = "the78mole"
__license__ = "MIT"

from moles_tools.env_updater import update_env_file

__all__ = ["update_env_file"]
